==> webkit2gtk_2.47.2.orig.tar.xz: webkitgtk-2.47.2/Source/WebCore/platform/calc/CalculationValue.cpp <==
/*
 * Copyright (C) 2011 Google Inc. All rights reserved.
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "CalculationValue.h"

#include "CalculationTree+Copy.h"
#include "CalculationTree+Evaluation.h"
#include <cmath>
#include <wtf/text/TextStream.h>

namespace WebCore {

Ref<CalculationValue> CalculationValue::create(Calculation::Tree&& tree)
{
    return adoptRef(*new CalculationValue(WTFMove(tree)));
}

CalculationValue::CalculationValue(Calculation::Tree&& tree)
    : m_tree(WTFMove(tree))
{
}

CalculationValue::~CalculationValue() = default;

Calculation::NumericValue CalculationValue::evaluate(Calculation::NumericValue percentResolutionLength) const
{
    auto result = Calculation::evaluate(m_tree, percentResolutionLength);
    if (std::isnan(result))
        return 0;
    return std::clamp(result, m_tree.range.min, m_tree.range.max);
}

Calculation::Tree CalculationValue::copyTree() const
{
    return Calculation::copy(m_tree);
}

Calculation::Child CalculationValue::copyRoot() const
{
    auto tree = copyTree();
    return { WTFMove(tree.root) };
}

bool CalculationValue::operator==(const CalculationValue& other) const
{
    return m_tree == other.m_tree;
}

TextStream& operator<<(TextStream& ts, const CalculationValue& value)
{
    return ts << "calc(" << value.tree() << ")";
}

} // namespace WebCore

==> webkit2gtk_2.47.3.orig.tar.xz: webkitgtk-2.47.3/Source/WebCore/platform/calc/CalculationValue.cpp <==
/*
 * Copyright (C) 2011 Google Inc. All rights reserved.
 * Copyright (C) 2014 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *     * Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above
 * copyright notice, this list of conditions and the following disclaimer
 * in the documentation and/or other materials provided with the
 * distribution.
 *     * Neither the name of Google Inc. nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "CalculationValue.h"

#include "CalculationTree+Copy.h"
#include "CalculationTree+Evaluation.h"
#include <cmath>
#include <wtf/text/TextStream.h>

namespace WebCore {

Ref<CalculationValue> CalculationValue::create(Calculation::Category category, Calculation::Range range, Calculation::Tree&& tree)
{
    return adoptRef(*new CalculationValue(category, range, WTFMove(tree)));
}

CalculationValue::CalculationValue(Calculation::Category category, Calculation::Range range, Calculation::Tree&& tree)
    : m_category(category)
    , m_range(range)
    , m_tree(WTFMove(tree))
{
}

CalculationValue::~CalculationValue() = default;

Calculation::NumericValue CalculationValue::evaluate(Calculation::NumericValue percentResolutionLength) const
{
    auto result = Calculation::evaluate(m_tree, percentResolutionLength);
    if (std::isnan(result))
        return 0;
    return std::clamp(result, m_range.min, m_range.max);
}

Calculation::Tree CalculationValue::copyTree() const
{
    return Calculation::copy(m_tree);
}

Calculation::Child CalculationValue::copyRoot() const
{
    auto tree = copyTree();
    return { WTFMove(tree.root) };
}

bool CalculationValue::operator==(const CalculationValue& other) const
{
    return m_tree == other.m_tree;
}

TextStream& operator<<(TextStream& ts, const CalculationValue& value)
{
    return ts << "calc(" << value.tree() << ")";
}

} // namespace WebCore
